# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Hooks library — installed package path for omniclaude.hooks.lib.

Modules here are the installed counterparts to the standalone scripts in
``plugins/onex/hooks/lib/``.  The installed package path is required for any
module that is imported via ``omniclaude.hooks.lib.*`` at runtime (e.g. from
``src/omniclaude/runtime/plugin.py``).
"""
