# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: create_followup_tickets orchestrator."""

from omniclaude.nodes.node_skill_create_followup_tickets_orchestrator.node import (
    NodeSkillCreateFollowupTicketsOrchestrator,
)

__all__ = ["NodeSkillCreateFollowupTicketsOrchestrator"]
