# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: setup_statusline orchestrator."""

from omniclaude.nodes.node_skill_setup_statusline_orchestrator.node import (
    NodeSkillSetupStatuslineOrchestrator,
)

__all__ = ["NodeSkillSetupStatuslineOrchestrator"]
