# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: slack_gate orchestrator."""

from omniclaude.nodes.node_skill_slack_gate_orchestrator.node import (
    NodeSkillSlackGateOrchestrator,
)

__all__ = ["NodeSkillSlackGateOrchestrator"]
