# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Protocols for the NodeLocalCodingOrchestrator node.

This package is intentionally minimal. The orchestrator does not define
protocol interfaces (it is not an effect node).
"""

__all__: list[str] = []
