# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: epic_team orchestrator."""

from omniclaude.nodes.node_skill_epic_team_orchestrator.node import (
    NodeSkillEpicTeamOrchestrator,
)

__all__ = ["NodeSkillEpicTeamOrchestrator"]
