# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: golden_path_validate orchestrator."""

from omniclaude.nodes.node_skill_golden_path_validate_orchestrator.node import (
    NodeSkillGoldenPathValidateOrchestrator,
)

__all__ = ["NodeSkillGoldenPathValidateOrchestrator"]
