# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: friction_triage orchestrator."""

from omniclaude.nodes.node_skill_friction_triage_orchestrator.node import (
    NodeSkillFrictionTriageOrchestrator,
)

__all__ = ["NodeSkillFrictionTriageOrchestrator"]
