# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: writing_skills orchestrator."""

from omniclaude.nodes.node_skill_writing_skills_orchestrator.node import (
    NodeSkillWritingSkillsOrchestrator,
)

__all__ = ["NodeSkillWritingSkillsOrchestrator"]
