# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT

from omniclaude.nodes.node_friction_observer_compute.node import (
    NodeFrictionObserverCompute,
)

__all__ = ["NodeFrictionObserverCompute"]
