# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Models for NodeTransitionSelectorEffect.

NOTE: ContractState, GoalCondition, TypedAction, and NavigationContext are
defined locally here until omnibase_core exports them (OMN-2540, OMN-2546).
At that point, imports should be updated to pull from omnibase_core.
"""

from omniclaude.nodes.node_transition_selector_effect.models.model_contract_state import (
    ContractStateMetadataDict,
    ModelContractState,
)
from omniclaude.nodes.node_transition_selector_effect.models.model_goal_condition import (
    ModelGoalCondition,
)
from omniclaude.nodes.node_transition_selector_effect.models.model_navigation_context import (
    ModelNavigationContext,
)
from omniclaude.nodes.node_transition_selector_effect.models.model_transition_selector_request import (
    ModelTransitionSelectorRequest,
)
from omniclaude.nodes.node_transition_selector_effect.models.model_transition_selector_result import (
    ModelTransitionSelectorResult,
    SelectionErrorKind,
)
from omniclaude.nodes.node_transition_selector_effect.models.model_typed_action import (
    ModelTypedAction,
)

__all__ = [
    "ContractStateMetadataDict",
    "ModelContractState",
    "ModelGoalCondition",
    "ModelNavigationContext",
    "ModelTransitionSelectorRequest",
    "ModelTransitionSelectorResult",
    "ModelTypedAction",
    "SelectionErrorKind",
]
