# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: linear_epic_org orchestrator."""

from omniclaude.nodes.node_skill_linear_epic_org_orchestrator.node import (
    NodeSkillLinearEpicOrgOrchestrator,
)

__all__ = ["NodeSkillLinearEpicOrgOrchestrator"]
