# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: deploy_local_plugin orchestrator."""

from omniclaude.nodes.node_skill_deploy_local_plugin_orchestrator.node import (
    NodeSkillDeployLocalPluginOrchestrator,
)

__all__ = ["NodeSkillDeployLocalPluginOrchestrator"]
