# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: auto_ticket_from_findings orchestrator."""

from omniclaude.nodes.node_skill_auto_ticket_from_findings_orchestrator.node import (
    NodeSkillAutoTicketFromFindingsOrchestrator,
)

__all__ = ["NodeSkillAutoTicketFromFindingsOrchestrator"]
