# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: linear_insights orchestrator."""

from omniclaude.nodes.node_skill_linear_insights_orchestrator.node import (
    NodeSkillLinearInsightsOrchestrator,
)

__all__ = ["NodeSkillLinearInsightsOrchestrator"]
