# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: dep_cascade_dedup orchestrator."""

from omniclaude.nodes.node_skill_dep_cascade_dedup_orchestrator.node import (
    NodeSkillDepCascadeDedupOrchestrator,
)

__all__ = ["NodeSkillDepCascadeDedupOrchestrator"]
