# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: decompose_epic orchestrator."""

from omniclaude.nodes.node_skill_decompose_epic_orchestrator.node import (
    NodeSkillDecomposeEpicOrchestrator,
)

__all__ = ["NodeSkillDecomposeEpicOrchestrator"]
