# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: sharing_skills orchestrator."""

from omniclaude.nodes.node_skill_sharing_skills_orchestrator.node import (
    NodeSkillSharingSkillsOrchestrator,
)

__all__ = ["NodeSkillSharingSkillsOrchestrator"]
