# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: scope_lock orchestrator."""

from omniclaude.nodes.node_skill_scope_lock_orchestrator.node import (
    NodeSkillScopeLockOrchestrator,
)

__all__ = ["NodeSkillScopeLockOrchestrator"]
