# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: ship_stalled_agents orchestrator."""

from omniclaude.nodes.node_skill_ship_stalled_agents_orchestrator.node import (
    NodeSkillShipStalledAgentsOrchestrator,
)

__all__ = ["NodeSkillShipStalledAgentsOrchestrator"]
