# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: self_correcting_epic orchestrator."""

from omniclaude.nodes.node_skill_self_correcting_epic_orchestrator.node import (
    NodeSkillSelfCorrectingEpicOrchestrator,
)

__all__ = ["NodeSkillSelfCorrectingEpicOrchestrator"]
