# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT

# Copyright (c) 2025 OmniNode Team
"""Skill node: dashboard_sweep orchestrator."""

from omniclaude.nodes.node_skill_dashboard_sweep_orchestrator.node import (
    NodeSkillDashboardSweepOrchestrator,
)

__all__ = ["NodeSkillDashboardSweepOrchestrator"]
