# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT

"""Configuration modules for omniclaude.lib.

This package contains configuration classes for various subsystems:
- IntelligenceConfig: Configuration for intelligence gathering system
"""

from .intelligence_config import IntelligenceConfig

__all__ = ["IntelligenceConfig"]
