# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: defense_in_depth orchestrator."""

from omniclaude.nodes.node_skill_defense_in_depth_orchestrator.node import (
    NodeSkillDefenseInDepthOrchestrator,
)

__all__ = ["NodeSkillDefenseInDepthOrchestrator"]
