# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Handlers for the GitHub PR watcher effect node."""

from omniclaude.nodes.node_github_pr_watcher_effect.handlers.watch_registry import (
    WatchRegistry,
)

__all__ = ["WatchRegistry"]
