# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: hostile_reviewer orchestrator."""

from omniclaude.nodes.node_skill_hostile_reviewer_orchestrator.node import (
    NodeSkillHostileReviewerOrchestrator,
)

__all__ = ["NodeSkillHostileReviewerOrchestrator"]
