# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: ultimate_validate orchestrator."""

from omniclaude.nodes.node_skill_ultimate_validate_orchestrator.node import (
    NodeSkillUltimateValidateOrchestrator,
)

__all__ = ["NodeSkillUltimateValidateOrchestrator"]
